@@ -1,5 +1,5 @@
 # -*- test-case-name: twisted.web.test.test_proxy -*-
-# Copyright (c) 2001-2007 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -167,7 +167,7 @@ class Proxy(HTTPChannel):
     """
     This class implements a simple web proxy.
 
-    Since it inherits from L{twisted.protocols.http.HTTPChannel}, to use it you
+    Since it inherits from L{twisted.web.http.HTTPChannel}, to use it you
     should do something like this::
 
         from twisted.web import http
@@ -275,7 +275,8 @@ class ReverseProxyResource(Resource):
         C{path} at the end.
         """
         return ReverseProxyResource(
-            self.host, self.port, self.path + '/' + urlquote(path, safe=""))
+            self.host, self.port, self.path + '/' + urlquote(path, safe=""),
+            self.reactor)
 
 
     def render(self, request):
