@@ -1,5 +1,5 @@
 # -*- test-case-name: twisted.web.test.test_web -*-
-# Copyright (c) 2001-2009 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 
@@ -19,22 +19,20 @@ from urllib import quote
 
 from zope.interface import implements
 
-try:
-    from twisted.protocols._c_urlarg import unquote
-except ImportError:
-    from urllib import unquote
+from urllib import unquote
 
 #some useful constants
 NOT_DONE_YET = 1
 
 # Twisted Imports
 from twisted.spread import pb
-from twisted.internet import defer, address, task
+from twisted.internet import address, task
 from twisted.web import iweb, http
 from twisted.python import log, reflect, failure, components
 from twisted import copyright
 from twisted.web import util as webutil, resource
 from twisted.web.error import UnsupportedMethod
+from twisted.web.microdom import escape
 
 # backwards compatability
 date_time_string = http.datetimeToString
@@ -53,11 +51,21 @@ def _addressToTuple(addr):
         return tuple(addr)
 
 class Request(pb.Copyable, http.Request, components.Componentized):
+    """
+    An HTTP request.
+
+    @ivar defaultContentType: A C{str} giving the default I{Content-Type} value
+        to send in responses if no other value is set.  C{None} disables the
+        default.
+    """
     implements(iweb.IRequest)
 
+    defaultContentType = "text/html"
+
     site = None
     appRootURL = None
     __pychecker__ = 'unusednames=issuer'
+    _inFakeHead = False
 
     def __init__(self, *args, **kw):
         http.Request.__init__(self, *args, **kw)
@@ -115,7 +123,6 @@ class Request(pb.Copyable, http.Request, components.Componentized):
         # set various default headers
         self.setHeader('server', version)
         self.setHeader('date', http.datetimeToString())
-        self.setHeader('content-type', "text/html")
 
         # Resource Identification
         self.prepath = []
@@ -126,8 +133,36 @@ class Request(pb.Copyable, http.Request, components.Componentized):
         except:
             self.processingFailed(failure.Failure())
 
+    def write(self, data):
+        """
+        Write data to the transport (if not responding to a HEAD request).
+
+        @param data: A string to write to the response.
+        """
+        if not self.startedWriting:
+            # Before doing the first write, check to see if a default
+            # Content-Type header should be supplied.
+            modified = self.code != http.NOT_MODIFIED
+            contentType = self.responseHeaders.getRawHeaders('content-type')
+            if modified and contentType is None and self.defaultContentType is not None:
+                self.responseHeaders.setRawHeaders(
+                    'content-type', [self.defaultContentType])
+
+        # Only let the write happen if we're not generating a HEAD response by
+        # faking out the request method.  Note, if we are doing that,
+        # startedWriting will never be true, and the above logic may run
+        # multiple times.  It will only actually change the responseHeaders once
+        # though, so it's still okay.
+        if not self._inFakeHead:
+            http.Request.write(self, data)
+
 
     def render(self, resrc):
+        """
+        Ask a resource to render itself.
+
+        @param resrc: a L{twisted.web.resource.IResource}.
+        """
         try:
             body = resrc.render(self)
         except UnsupportedMethod, e:
@@ -140,6 +175,7 @@ class Request(pb.Copyable, http.Request, components.Componentized):
                 log.msg("Using GET to fake a HEAD request for %s" %
                         (resrc,))
                 self.method = "GET"
+                self._inFakeHead = True
                 body = resrc.render(self)
 
                 if body is NOT_DONE_YET:
@@ -149,6 +185,8 @@ class Request(pb.Copyable, http.Request, components.Componentized):
                 else:
                     self.setHeader('content-length', str(len(body)))
 
+                self._inFakeHead = False
+                self.method = "HEAD"
                 self.write('')
                 self.finish()
                 return
@@ -156,11 +194,11 @@ class Request(pb.Copyable, http.Request, components.Componentized):
             if self.method in (supportedMethods):
                 # We MUST include an Allow header
                 # (RFC 2616, 10.4.6 and 14.7)
-                self.setHeader('Allow', allowedMethods)
+                self.setHeader('Allow', ', '.join(allowedMethods))
                 s = ('''Your browser approached me (at %(URI)s) with'''
                      ''' the method "%(method)s".  I only allow'''
                      ''' the method%(plural)s %(allowed)s here.''' % {
-                    'URI': self.uri,
+                    'URI': escape(self.uri),
                     'method': self.method,
                     'plural': ((len(allowedMethods) > 1) and 's') or '',
                     'allowed': string.join(allowedMethods, ', ')
@@ -169,9 +207,10 @@ class Request(pb.Copyable, http.Request, components.Componentized):
                                            "Method Not Allowed", s)
                 body = epage.render(self)
             else:
-                epage = resource.ErrorPage(http.NOT_IMPLEMENTED, "Huh?",
-                                           "I don't know how to treat a"
-                                           " %s request." % (self.method,))
+                epage = resource.ErrorPage(
+                    http.NOT_IMPLEMENTED, "Huh?",
+                    "I don't know how to treat a %s request." %
+                    (escape(self.method),))
                 body = epage.render(self)
         # end except UnsupportedMethod
 
