@@ -1,4 +1,4 @@
-# Copyright (c) 2009 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -21,6 +21,20 @@ print
 print "cgi output"
 '''
 
+DUAL_HEADER_CGI = '''\
+print "Header: spam"
+print "Header: eggs"
+print
+print "cgi output"
+'''
+
+SPECIAL_HEADER_CGI = '''\
+print "Server: monkeys"
+print "Date: last year"
+print
+print "cgi output"
+'''
+
 READINPUT_CGI = '''\
 # this is an example of a correctly-written CGI script which reads a body
 # from stdin, which only reads env['CONTENT_LENGTH'] bytes.
@@ -47,9 +61,14 @@ print
 print "readallinput ok"
 '''
 
+NO_DUPLICATE_CONTENT_TYPE_HEADER_CGI = '''\
+print "content-type: text/cgi-duplicate-test"
+print
+print "cgi output"
+'''
+
 class PythonScript(twcgi.FilteredScript):
     filter = sys.executable
-    filters = sys.executable,  # web2's version
 
 class CGI(unittest.TestCase):
     """
@@ -72,18 +91,79 @@ class CGI(unittest.TestCase):
             return self.p.stopListening()
 
 
-    def testCGI(self):
+    def writeCGI(self, source):
         cgiFilename = os.path.abspath(self.mktemp())
         cgiFile = file(cgiFilename, 'wt')
-        cgiFile.write(DUMMY_CGI)
+        cgiFile.write(source)
         cgiFile.close()
+        return cgiFilename
+
+
+    def testCGI(self):
+        cgiFilename = self.writeCGI(DUMMY_CGI)
 
         portnum = self.startServer(cgiFilename)
         d = client.getPage("http://localhost:%d/cgi" % portnum)
         d.addCallback(self._testCGI_1)
         return d
+
+
     def _testCGI_1(self, res):
-        self.failUnlessEqual(res, "cgi output" + os.linesep)
+        self.assertEqual(res, "cgi output" + os.linesep)
+
+
+    def test_protectedServerAndDate(self):
+        """
+        If the CGI script emits a I{Server} or I{Date} header, these are
+        ignored.
+        """
+        cgiFilename = self.writeCGI(SPECIAL_HEADER_CGI)
+
+        portnum = self.startServer(cgiFilename)
+        url = "http://localhost:%d/cgi" % (portnum,)
+        factory = client.HTTPClientFactory(url)
+        reactor.connectTCP('localhost', portnum, factory)
+        def checkResponse(ignored):
+            self.assertNotIn('monkeys', factory.response_headers['server'])
+            self.assertNotIn('last year', factory.response_headers['date'])
+        factory.deferred.addCallback(checkResponse)
+        return factory.deferred
+
+
+    def test_noDuplicateContentTypeHeaders(self):
+        """
+        If the CGI script emits a I{content-type} header, make sure that the
+        server doesn't add an additional (duplicate) one, as per ticket 4786.
+        """
+        cgiFilename = self.writeCGI(NO_DUPLICATE_CONTENT_TYPE_HEADER_CGI)
+
+        portnum = self.startServer(cgiFilename)
+        url = "http://localhost:%d/cgi" % (portnum,)
+        factory = client.HTTPClientFactory(url)
+        reactor.connectTCP('localhost', portnum, factory)
+        def checkResponse(ignored):
+            self.assertEqual(
+                factory.response_headers['content-type'], ['text/cgi-duplicate-test'])
+        factory.deferred.addCallback(checkResponse)
+        return factory.deferred
+
+
+    def test_duplicateHeaderCGI(self):
+        """
+        If a CGI script emits two instances of the same header, both are sent in
+        the response.
+        """
+        cgiFilename = self.writeCGI(DUAL_HEADER_CGI)
+
+        portnum = self.startServer(cgiFilename)
+        url = "http://localhost:%d/cgi" % (portnum,)
+        factory = client.HTTPClientFactory(url)
+        reactor.connectTCP('localhost', portnum, factory)
+        def checkResponse(ignored):
+            self.assertEqual(
+                factory.response_headers['header'], ['spam', 'eggs'])
+        factory.deferred.addCallback(checkResponse)
+        return factory.deferred
 
 
     def testReadEmptyInput(self):
@@ -98,7 +178,7 @@ class CGI(unittest.TestCase):
         return d
     testReadEmptyInput.timeout = 5
     def _testReadEmptyInput_1(self, res):
-        self.failUnlessEqual(res, "readinput ok%s" % os.linesep)
+        self.assertEqual(res, "readinput ok%s" % os.linesep)
 
     def testReadInput(self):
         cgiFilename = os.path.abspath(self.mktemp())
@@ -114,7 +194,7 @@ class CGI(unittest.TestCase):
         return d
     testReadInput.timeout = 5
     def _testReadInput_1(self, res):
-        self.failUnlessEqual(res, "readinput ok%s" % os.linesep)
+        self.assertEqual(res, "readinput ok%s" % os.linesep)
 
 
     def testReadAllInput(self):
@@ -131,7 +211,7 @@ class CGI(unittest.TestCase):
         return d
     testReadAllInput.timeout = 5
     def _testReadAllInput_1(self, res):
-        self.failUnlessEqual(res, "readallinput ok%s" % os.linesep)
+        self.assertEqual(res, "readallinput ok%s" % os.linesep)
 
 
 
@@ -188,3 +268,36 @@ class CGIProcessProtocolTests(unittest.TestCase):
         protocol.processEnded(failure.Failure(error.ProcessTerminated()))
         self.assertEqual(request.responseCode, INTERNAL_SERVER_ERROR)
 
+
+
+class CGIDeprecationTests(unittest.TestCase):
+    """
+    Tests for deprecations in L{twisted.web.twcgi}.
+    """
+
+    def test_PHP3ScriptIsDeprecated(self):
+        """
+        L{twcgi.PHP3Script} is deprecated.
+        """
+        twcgi.PHP3Script
+
+        warnings = self.flushWarnings([self.test_PHP3ScriptIsDeprecated])
+        self.assertEqual(len(warnings), 1)
+        self.assertEqual(warnings[0]['category'], DeprecationWarning)
+        self.assertIn("PHP3Script is deprecated. "
+                      "Use twisted.web.twcgi.FilteredScript instead.",
+                      warnings[0]['message'])
+
+
+    def test_PHPScriptIsDeprecated(self):
+        """
+        L{twcgi.PHPScript} is deprecated.
+        """
+        twcgi.PHPScript
+
+        warnings = self.flushWarnings([self.test_PHPScriptIsDeprecated])
+        self.assertEqual(len(warnings), 1)
+        self.assertEqual(warnings[0]['category'], DeprecationWarning)
+        self.assertIn("PHPScript is deprecated. "
+                      "Use twisted.web.twcgi.FilteredScript instead.",
+                      warnings[0]['message'])
