@@ -1,4 +1,4 @@
-# Copyright (c) 2001-2010 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -31,7 +31,7 @@ class DateTimeTest(unittest.TestCase):
             time = random.randint(0, 2000000000)
             timestr = http.datetimeToString(time)
             time2 = http.stringToDatetime(timestr)
-            self.assertEquals(time, time2)
+            self.assertEqual(time, time2)
 
 
 class DummyHTTPHandler(http.Request):
@@ -216,7 +216,7 @@ class HTTP0_9TestCase(HTTP1_0TestCase):
 
 
     def assertResponseEquals(self, response, expectedResponse):
-        self.assertEquals(response, expectedResponse)
+        self.assertEqual(response, expectedResponse)
 
 
 class HTTPLoopbackTestCase(unittest.TestCase):
@@ -232,20 +232,20 @@ class HTTPLoopbackTestCase(unittest.TestCase):
 
     def _handleStatus(self, version, status, message):
         self.gotStatus = 1
-        self.assertEquals(version, "HTTP/1.0")
-        self.assertEquals(status, "200")
+        self.assertEqual(version, "HTTP/1.0")
+        self.assertEqual(status, "200")
 
     def _handleResponse(self, data):
         self.gotResponse = 1
-        self.assertEquals(data, "'''\n10\n0123456789'''\n")
+        self.assertEqual(data, "'''\n10\n0123456789'''\n")
 
     def _handleHeader(self, key, value):
         self.numHeaders = self.numHeaders + 1
-        self.assertEquals(self.expectedHeaders[key.lower()], value)
+        self.assertEqual(self.expectedHeaders[key.lower()], value)
 
     def _handleEndHeaders(self):
         self.gotEndHeaders = 1
-        self.assertEquals(self.numHeaders, 4)
+        self.assertEqual(self.numHeaders, 4)
 
     def testLoopback(self):
         server = http.HTTPChannel()
@@ -298,9 +298,9 @@ class PersistenceTestCase(unittest.TestCase):
         c = http.HTTPChannel()
         for req, version, correctResult, resultHeaders in self.ptests:
             result = c.checkPersistence(req, version)
-            self.assertEquals(result, correctResult)
+            self.assertEqual(result, correctResult)
             for header in resultHeaders.keys():
-                self.assertEquals(req.responseHeaders.getRawHeaders(header, None), resultHeaders[header])
+                self.assertEqual(req.responseHeaders.getRawHeaders(header, None), resultHeaders[header])
 
 
 
@@ -583,7 +583,7 @@ class ChunkingTestCase(unittest.TestCase):
 
     def testChunks(self):
         for s in self.strings:
-            self.assertEquals((s, ''), http.fromChunk(''.join(http.toChunk(s))))
+            self.assertEqual((s, ''), http.fromChunk(''.join(http.toChunk(s))))
         self.assertRaises(ValueError, http.fromChunk, '-5\r\nmalformed!\r\n')
 
     def testConcatenatedChunks(self):
@@ -597,7 +597,7 @@ class ChunkingTestCase(unittest.TestCase):
                 result.append(data)
             except ValueError:
                 pass
-        self.assertEquals(result, self.strings)
+        self.assertEqual(result, self.strings)
 
 
 
@@ -618,7 +618,7 @@ class ParsingTestCase(unittest.TestCase):
             a.dataReceived(byte)
         a.connectionLost(IOError("all done"))
         if success:
-            self.assertEquals(self.didRequest, 1)
+            self.assertEqual(self.didRequest, 1)
             del self.didRequest
         else:
             self.assert_(not hasattr(self, "didRequest"))
@@ -635,8 +635,8 @@ class ParsingTestCase(unittest.TestCase):
         class Request(http.Request):
             l = []
             def process(self):
-                testcase.assertEquals(self.getUser(), self.l[0])
-                testcase.assertEquals(self.getPassword(), self.l[1])
+                testcase.assertEqual(self.getUser(), self.l[0])
+                testcase.assertEqual(self.getPassword(), self.l[1])
         for u, p in [("foo", "bar"), ("hello", "there:z")]:
             Request.l[:] = [u, p]
             s = "%s:%s" % (u, p)
@@ -665,9 +665,9 @@ class ParsingTestCase(unittest.TestCase):
 
         self.runRequest('\n'.join(requestLines), MyRequest, 0)
         [request] = processed
-        self.assertEquals(
+        self.assertEqual(
             request.requestHeaders.getRawHeaders('foo'), ['bar'])
-        self.assertEquals(
+        self.assertEqual(
             request.requestHeaders.getRawHeaders('bAz'), ['Quux', 'quux'])
 
 
@@ -747,9 +747,9 @@ Cookie: rabbit="eat carrot"; ninja=secret; spam="hey 1=1!"
 
         class MyRequest(http.Request):
             def process(self):
-                testcase.assertEquals(self.getCookie('rabbit'), '"eat carrot"')
-                testcase.assertEquals(self.getCookie('ninja'), 'secret')
-                testcase.assertEquals(self.getCookie('spam'), '"hey 1=1!"')
+                testcase.assertEqual(self.getCookie('rabbit'), '"eat carrot"')
+                testcase.assertEqual(self.getCookie('ninja'), 'secret')
+                testcase.assertEqual(self.getCookie('spam'), '"hey 1=1!"')
                 testcase.didRequest = 1
                 self.finish()
 
@@ -763,10 +763,10 @@ GET /?key=value&multiple=two+words&multiple=more%20words&empty= HTTP/1.0
         testcase = self
         class MyRequest(http.Request):
             def process(self):
-                testcase.assertEquals(self.method, "GET")
-                testcase.assertEquals(self.args["key"], ["value"])
-                testcase.assertEquals(self.args["empty"], [""])
-                testcase.assertEquals(self.args["multiple"], ["two words", "more words"])
+                testcase.assertEqual(self.method, "GET")
+                testcase.assertEqual(self.args["key"], ["value"])
+                testcase.assertEqual(self.args["empty"], [""])
+                testcase.assertEqual(self.args["multiple"], ["two words", "more words"])
                 testcase.didRequest = 1
                 self.finish()
 
@@ -813,14 +813,14 @@ Content-Type: application/x-www-form-urlencoded
         testcase = self
         class MyRequest(http.Request):
             def process(self):
-                testcase.assertEquals(self.method, "POST")
-                testcase.assertEquals(self.args["key"], ["value"])
-                testcase.assertEquals(self.args["empty"], [""])
-                testcase.assertEquals(self.args["multiple"], ["two words", "more words"])
+                testcase.assertEqual(self.method, "POST")
+                testcase.assertEqual(self.args["key"], ["value"])
+                testcase.assertEqual(self.args["empty"], [""])
+                testcase.assertEqual(self.args["multiple"], ["two words", "more words"])
 
                 # Reading from the content file-like must produce the entire
                 # request body.
-                testcase.assertEquals(self.content.read(), query)
+                testcase.assertEqual(self.content.read(), query)
                 testcase.didRequest = 1
                 self.finish()
 
@@ -881,32 +881,14 @@ Hello,
 
 
 class QueryArgumentsTestCase(unittest.TestCase):
-    def testUnquote(self):
-        try:
-            from twisted.protocols import _c_urlarg
-        except ImportError:
-            raise unittest.SkipTest("_c_urlarg module is not available")
-        # work exactly like urllib.unquote, including stupid things
-        # % followed by a non-hexdigit in the middle and in the end
-        self.failUnlessEqual(urllib.unquote("%notreally%n"),
-            _c_urlarg.unquote("%notreally%n"))
-        # % followed by hexdigit, followed by non-hexdigit
-        self.failUnlessEqual(urllib.unquote("%1quite%1"),
-            _c_urlarg.unquote("%1quite%1"))
-        # unquoted text, followed by some quoted chars, ends in a trailing %
-        self.failUnlessEqual(urllib.unquote("blah%21%40%23blah%"),
-            _c_urlarg.unquote("blah%21%40%23blah%"))
-        # Empty string
-        self.failUnlessEqual(urllib.unquote(""), _c_urlarg.unquote(""))
-
     def testParseqs(self):
-        self.failUnlessEqual(cgi.parse_qs("a=b&d=c;+=f"),
+        self.assertEqual(cgi.parse_qs("a=b&d=c;+=f"),
             http.parse_qs("a=b&d=c;+=f"))
         self.failUnlessRaises(ValueError, http.parse_qs, "blah",
             strict_parsing = 1)
-        self.failUnlessEqual(cgi.parse_qs("a=&b=c", keep_blank_values = 1),
+        self.assertEqual(cgi.parse_qs("a=&b=c", keep_blank_values = 1),
             http.parse_qs("a=&b=c", keep_blank_values = 1))
-        self.failUnlessEqual(cgi.parse_qs("a=&b=c"),
+        self.assertEqual(cgi.parse_qs("a=&b=c"),
             http.parse_qs("a=&b=c"))
 
 
@@ -972,13 +954,6 @@ class QueryArgumentsTestCase(unittest.TestCase):
         self.assertRaises(TypeError, http.urlparse, u'http://example.org/path')
 
 
-    def testEscchar(self):
-        try:
-            from twisted.protocols import _c_urlarg
-        except ImportError:
-            raise unittest.SkipTest("_c_urlarg module is not available")
-        self.failUnlessEqual("!@#+b",
-            _c_urlarg.unquote("+21+40+23+b", "+"))
 
 class ClientDriver(http.HTTPClient):
     def handleStatus(self, version, status, message):
@@ -990,23 +965,23 @@ class ClientStatusParsing(unittest.TestCase):
     def testBaseline(self):
         c = ClientDriver()
         c.lineReceived('HTTP/1.0 201 foo')
-        self.failUnlessEqual(c.version, 'HTTP/1.0')
-        self.failUnlessEqual(c.status, '201')
-        self.failUnlessEqual(c.message, 'foo')
+        self.assertEqual(c.version, 'HTTP/1.0')
+        self.assertEqual(c.status, '201')
+        self.assertEqual(c.message, 'foo')
 
     def testNoMessage(self):
         c = ClientDriver()
         c.lineReceived('HTTP/1.0 201')
-        self.failUnlessEqual(c.version, 'HTTP/1.0')
-        self.failUnlessEqual(c.status, '201')
-        self.failUnlessEqual(c.message, '')
+        self.assertEqual(c.version, 'HTTP/1.0')
+        self.assertEqual(c.status, '201')
+        self.assertEqual(c.message, '')
 
     def testNoMessage_trailingSpace(self):
         c = ClientDriver()
         c.lineReceived('HTTP/1.0 201 ')
-        self.failUnlessEqual(c.version, 'HTTP/1.0')
-        self.failUnlessEqual(c.status, '201')
-        self.failUnlessEqual(c.message, '')
+        self.assertEqual(c.version, 'HTTP/1.0')
+        self.assertEqual(c.status, '201')
+        self.assertEqual(c.message, '')
 
 
 
@@ -1056,7 +1031,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         """
         req = http.Request(DummyChannel(), None)
         req.requestHeaders.setRawHeaders("test", ["lemur"])
-        self.assertEquals(req.getHeader("test"), "lemur")
+        self.assertEqual(req.getHeader("test"), "lemur")
 
 
     def test_getHeaderReceivedMultiples(self):
@@ -1066,7 +1041,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         """
         req = http.Request(DummyChannel(), None)
         req.requestHeaders.setRawHeaders("test", ["lemur", "panda"])
-        self.assertEquals(req.getHeader("test"), "panda")
+        self.assertEqual(req.getHeader("test"), "panda")
 
 
     def test_getHeaderNotFound(self):
@@ -1075,7 +1050,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         request header which is not present.
         """
         req = http.Request(DummyChannel(), None)
-        self.assertEquals(req.getHeader("test"), None)
+        self.assertEqual(req.getHeader("test"), None)
 
 
     def test_getAllHeaders(self):
@@ -1085,7 +1060,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         """
         req = http.Request(DummyChannel(), None)
         req.requestHeaders.setRawHeaders("test", ["lemur"])
-        self.assertEquals(req.getAllHeaders(), {"test": "lemur"})
+        self.assertEqual(req.getAllHeaders(), {"test": "lemur"})
 
 
     def test_getAllHeadersNoHeaders(self):
@@ -1094,7 +1069,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         request headers.
         """
         req = http.Request(DummyChannel(), None)
-        self.assertEquals(req.getAllHeaders(), {})
+        self.assertEqual(req.getAllHeaders(), {})
 
 
     def test_getAllHeadersMultipleHeaders(self):
@@ -1104,7 +1079,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         """
         req = http.Request(DummyChannel(), None)
         req.requestHeaders.setRawHeaders("test", ["lemur", "panda"])
-        self.assertEquals(req.getAllHeaders(), {"test": "panda"})
+        self.assertEqual(req.getAllHeaders(), {"test": "panda"})
 
 
     def test_setResponseCode(self):
@@ -1149,20 +1124,58 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
     def test_setHost(self):
         """
         L{http.Request.setHost} sets the value of the host request header.
+        The port should not be added because it is the default.
         """
         req = http.Request(DummyChannel(), None)
+        req.setHost("example.com", 80)
+        self.assertEqual(
+            req.requestHeaders.getRawHeaders("host"), ["example.com"])
+
+
+    def test_setHostSSL(self):
+        """
+        L{http.Request.setHost} sets the value of the host request header.
+        The port should not be added because it is the default.
+        """
+        d = DummyChannel()
+        d.transport = DummyChannel.SSL()
+        req = http.Request(d, None)
         req.setHost("example.com", 443)
         self.assertEqual(
             req.requestHeaders.getRawHeaders("host"), ["example.com"])
 
 
+    def test_setHostNonDefaultPort(self):
+        """
+        L{http.Request.setHost} sets the value of the host request header.
+        The port should be added because it is not the default.
+        """
+        req = http.Request(DummyChannel(), None)
+        req.setHost("example.com", 81)
+        self.assertEqual(
+            req.requestHeaders.getRawHeaders("host"), ["example.com:81"])
+
+
+    def test_setHostSSLNonDefaultPort(self):
+        """
+        L{http.Request.setHost} sets the value of the host request header.
+        The port should be added because it is not the default.
+        """
+        d = DummyChannel()
+        d.transport = DummyChannel.SSL()
+        req = http.Request(d, None)
+        req.setHost("example.com", 81)
+        self.assertEqual(
+            req.requestHeaders.getRawHeaders("host"), ["example.com:81"])
+
+
     def test_setHeader(self):
         """
         L{http.Request.setHeader} sets the value of the given response header.
         """
         req = http.Request(DummyChannel(), None)
         req.setHeader("test", "lemur")
-        self.assertEquals(req.responseHeaders.getRawHeaders("test"), ["lemur"])
+        self.assertEqual(req.responseHeaders.getRawHeaders("test"), ["lemur"])
 
 
     def test_firstWrite(self):
@@ -1246,7 +1259,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         req.requestHeaders.setRawHeaders(
             "cookie", ['test="lemur"; test2="panda"'])
         req.parseCookies()
-        self.assertEquals(req.received_cookies, {"test": '"lemur"',
+        self.assertEqual(req.received_cookies, {"test": '"lemur"',
                                                  "test2": '"panda"'})
 
 
@@ -1259,7 +1272,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         req.requestHeaders.setRawHeaders(
             "cookie", ['test="lemur"', 'test2="panda"'])
         req.parseCookies()
-        self.assertEquals(req.received_cookies, {"test": '"lemur"',
+        self.assertEqual(req.received_cookies, {"test": '"lemur"',
                                                  "test2": '"panda"'})
 
 
@@ -1304,7 +1317,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         req = http.Request(DummyChannel(), True)
         producer = DummyProducer()
         req.registerProducer(producer, True)
-        self.assertEquals(['pause'], producer.events)
+        self.assertEqual(['pause'], producer.events)
 
 
     def test_registerProducerWhenQueuedDoesntPausePullProducer(self):
@@ -1316,7 +1329,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         req = http.Request(DummyChannel(), True)
         producer = DummyProducer()
         req.registerProducer(producer, False)
-        self.assertEquals([], producer.events)
+        self.assertEqual([], producer.events)
 
 
     def test_registerProducerWhenQueuedDoesntRegisterPushProducer(self):
@@ -1366,7 +1379,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         req = http.Request(DummyChannel(), False)
         producer = DummyProducer()
         req.registerProducer(producer, True)
-        self.assertEquals([(producer, True)], req.transport.producers)
+        self.assertEqual([(producer, True)], req.transport.producers)
 
 
     def test_registerProducerWhenNotQueuedRegistersPullProducer(self):
@@ -1378,7 +1391,7 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         req = http.Request(DummyChannel(), False)
         producer = DummyProducer()
         req.registerProducer(producer, False)
-        self.assertEquals([(producer, False)], req.transport.producers)
+        self.assertEqual([(producer, False)], req.transport.producers)
 
 
     def test_connectionLostNotification(self):
@@ -1407,6 +1420,22 @@ class RequestTests(unittest.TestCase, ResponseTestMixin):
         return finished
 
 
+    def test_writeAfterFinish(self):
+        """
+        Calling L{Request.write} after L{Request.finish} has been called results
+        in a L{RuntimeError} being raised.
+        """
+        request = http.Request(DummyChannel(), False)
+        finished = request.notifyFinish()
+        # Force the request to have a non-None content attribute.  This is
+        # probably a bug in Request.
+        request.gotLength(1)
+        request.write('foobar')
+        request.finish()
+        self.assertRaises(RuntimeError, request.write, 'foobar')
+        return finished
+
+
     def test_finishAfterConnectionLost(self):
         """
         Calling L{Request.finish} after L{Request.connectionLost} has been
@@ -1446,7 +1475,7 @@ class MultilineHeadersTestCase(unittest.TestCase):
         Dummy implementation of L{HTTPClient.handleHeader}.
         """
         self.handleHeaderCalled = True
-        self.assertEquals(val, self.expectedHeaders[key])
+        self.assertEqual(val, self.expectedHeaders[key])
 
 
     def ourHandleEndHeaders(self):
@@ -1477,7 +1506,7 @@ class MultilineHeadersTestCase(unittest.TestCase):
         self.assertTrue(self.handleHeaderCalled)
         self.assertTrue(self.handleEndHeadersCalled)
 
-        self.assertEquals(c.length, 10)
+        self.assertEqual(c.length, 10)
 
 
     def test_noHeaders(self):
@@ -1496,8 +1525,8 @@ class MultilineHeadersTestCase(unittest.TestCase):
         self.assertFalse(self.handleHeaderCalled)
         self.assertTrue(self.handleEndHeadersCalled)
 
-        self.assertEquals(c.version, 'HTTP/1.0')
-        self.assertEquals(c.status, '201')
+        self.assertEqual(c.version, 'HTTP/1.0')
+        self.assertEqual(c.status, '201')
 
 
     def test_multilineHeaders(self):
@@ -1526,6 +1555,109 @@ class MultilineHeadersTestCase(unittest.TestCase):
         c.lineReceived('')
         self.assertTrue(self.handleEndHeadersCalled)
 
-        self.assertEquals(c.version, 'HTTP/1.0')
-        self.assertEquals(c.status, '201')
-        self.assertEquals(c.length, 10)
+        self.assertEqual(c.version, 'HTTP/1.0')
+        self.assertEqual(c.status, '201')
+        self.assertEqual(c.length, 10)
+
+
+
+class Expect100ContinueServerTests(unittest.TestCase):
+    """
+    Test that the HTTP server handles 'Expect: 100-continue' header correctly.
+
+    The tests in this class all assume a simplistic behavior where user code
+    cannot choose to deny a request. Once ticket #288 is implemented and user
+    code can run before the body of a POST is processed this should be
+    extended to support overriding this behavior.
+    """
+
+    def test_HTTP10(self):
+        """
+        HTTP/1.0 requests do not get 100-continue returned, even if 'Expect:
+        100-continue' is included (RFC 2616 10.1.1).
+        """
+        transport = StringTransport()
+        channel = http.HTTPChannel()
+        channel.requestFactory = DummyHTTPHandler
+        channel.makeConnection(transport)
+        channel.dataReceived("GET / HTTP/1.0\r\n")
+        channel.dataReceived("Host: www.example.com\r\n")
+        channel.dataReceived("Content-Length: 3\r\n")
+        channel.dataReceived("Expect: 100-continue\r\n")
+        channel.dataReceived("\r\n")
+        self.assertEqual(transport.value(), "")
+        channel.dataReceived("abc")
+        self.assertEqual(transport.value(),
+                         "HTTP/1.0 200 OK\r\n"
+                         "Command: GET\r\n"
+                         "Content-Length: 13\r\n"
+                         "Version: HTTP/1.0\r\n"
+                         "Request: /\r\n\r\n'''\n3\nabc'''\n")
+
+
+    def test_expect100ContinueHeader(self):
+        """
+        If a HTTP/1.1 client sends a 'Expect: 100-continue' header, the server
+        responds with a 100 response code before handling the request body, if
+        any. The normal resource rendering code will then be called, which
+        will send an additional response code.
+        """
+        transport = StringTransport()
+        channel = http.HTTPChannel()
+        channel.requestFactory = DummyHTTPHandler
+        channel.makeConnection(transport)
+        channel.dataReceived("GET / HTTP/1.1\r\n")
+        channel.dataReceived("Host: www.example.com\r\n")
+        channel.dataReceived("Expect: 100-continue\r\n")
+        channel.dataReceived("Content-Length: 3\r\n")
+        # The 100 continue response is not sent until all headers are
+        # received:
+        self.assertEqual(transport.value(), "")
+        channel.dataReceived("\r\n")
+        # The 100 continue response is sent *before* the body is even
+        # received:
+        self.assertEqual(transport.value(), "HTTP/1.1 100 Continue\r\n\r\n")
+        channel.dataReceived("abc")
+        self.assertEqual(transport.value(),
+                         "HTTP/1.1 100 Continue\r\n\r\n"
+                         "HTTP/1.1 200 OK\r\n"
+                         "Command: GET\r\n"
+                         "Content-Length: 13\r\n"
+                         "Version: HTTP/1.1\r\n"
+                         "Request: /\r\n\r\n'''\n3\nabc'''\n")
+
+
+    def test_expect100ContinueWithPipelining(self):
+        """
+        If a HTTP/1.1 client sends a 'Expect: 100-continue' header, followed
+        by another pipelined request, the 100 response does not interfere with
+        the response to the second request.
+        """
+        transport = StringTransport()
+        channel = http.HTTPChannel()
+        channel.requestFactory = DummyHTTPHandler
+        channel.makeConnection(transport)
+        channel.dataReceived(
+            "GET / HTTP/1.1\r\n"
+            "Host: www.example.com\r\n"
+            "Expect: 100-continue\r\n"
+            "Content-Length: 3\r\n"
+            "\r\nabc"
+            "POST /foo HTTP/1.1\r\n"
+            "Host: www.example.com\r\n"
+            "Content-Length: 4\r\n"
+            "\r\ndefg")
+        self.assertEqual(transport.value(),
+                         "HTTP/1.1 100 Continue\r\n\r\n"
+                         "HTTP/1.1 200 OK\r\n"
+                         "Command: GET\r\n"
+                         "Content-Length: 13\r\n"
+                         "Version: HTTP/1.1\r\n"
+                         "Request: /\r\n\r\n"
+                         "'''\n3\nabc'''\n"
+                         "HTTP/1.1 200 OK\r\n"
+                         "Command: POST\r\n"
+                         "Content-Length: 14\r\n"
+                         "Version: HTTP/1.1\r\n"
+                         "Request: /foo\r\n\r\n"
+                         "'''\n4\ndefg'''\n")
