@@ -29,7 +29,7 @@ from twisted.web._newclient import BadHeaders, ResponseDone, PotentialDataLoss,
 from twisted.web._newclient import TransportProxyProducer, LengthEnforcingConsumer, makeStatefulDispatcher
 from twisted.web.http_headers import Headers
 from twisted.web.http import _DataLoss
-from twisted.web.iweb import IBodyProducer
+from twisted.web.iweb import IBodyProducer, IResponse
 
 
 
@@ -972,7 +972,7 @@ class HTTP11ClientProtocolTests(TestCase):
 
         def check(ignore):
             error = errors[0]
-            self.assertEquals(error['why'],
+            self.assertEqual(error['why'],
                               'Error writing request, but not in valid state '
                               'to finalize request: CONNECTION_LOST')
 
@@ -1054,6 +1054,35 @@ class HTTP11ClientProtocolTests(TestCase):
         return d
 
 
+    def test_connectionLostAfterReceivingResponseBeforeRequestGenerationDone(self):
+        """
+        If response bytes are delivered to L{HTTP11ClientProtocol} before the
+        request completes, calling L{connectionLost} on the protocol will
+        result in protocol being moved to C{'CONNECTION_LOST'} state.
+        """
+        request = SlowRequest()
+        d = self.protocol.request(request)
+        self.protocol.dataReceived(
+            "HTTP/1.1 400 BAD REQUEST\r\n"
+            "Content-Length: 9\r\n"
+            "\r\n"
+            "tisk tisk")
+        def cbResponse(response):
+            p = AccumulatingProtocol()
+            whenFinished = p.closedDeferred = Deferred()
+            response.deliverBody(p)
+            return whenFinished.addCallback(
+                lambda ign: (response, p.data))
+        d.addCallback(cbResponse)
+        def cbAllResponse(ignore):
+            request.finished.callback(None)
+            # Nothing dire will happen when the connection is lost
+            self.protocol.connectionLost(Failure(ArbitraryException()))
+            self.assertEqual(self.protocol._state, 'CONNECTION_LOST')
+        d.addCallback(cbAllResponse)
+        return d
+
+
     def test_receiveResponseBody(self):
         """
         The C{deliverBody} method of the response object with which the
@@ -1273,9 +1302,15 @@ class HTTP11ClientProtocolTests(TestCase):
             self.assertTrue(transport.disconnecting)
             protocol.connectionLost(Failure(ConnectionDone()))
 
+
+        def checkError(error):
+            self.assertIsInstance(error.response, Response)
+
+
         result.addCallback(deliverBody)
-        return assertResponseFailed(self, testResult,
-                                    [ConnectionAborted, _DataLoss])
+        deferred = assertResponseFailed(self, testResult,
+                                        [ConnectionAborted, _DataLoss])
+        return deferred.addCallback(checkError)
 
 
 
@@ -1559,7 +1594,7 @@ class RequestTests(TestCase):
         """
         producer = StringProducer(3)
         request = Request('POST', '/bar', _boringHeaders, producer)
-        writeDeferred = request.writeTo(self.transport)
+        request.writeTo(self.transport)
 
         finishedConsuming = producer.consumer._finished
 
@@ -1707,7 +1742,7 @@ class RequestTests(TestCase):
         """
         producer = StringProducer(3)
         request = Request('GET', '/', _boringHeaders, producer)
-        d = request.writeTo(self.transport)
+        request.writeTo(self.transport)
         self.assertFalse(producer.stopped)
         request.stopWriting()
         self.assertTrue(producer.stopped)
@@ -1724,7 +1759,7 @@ class RequestTests(TestCase):
         producer.stopProducing = brokenStopProducing
 
         request = Request('GET', '/', _boringHeaders, producer)
-        d = request.writeTo(self.transport)
+        request.writeTo(self.transport)
         request.stopWriting()
         self.assertEqual(
             len(self.flushLoggedErrors(ArbitraryException)), 1)
@@ -1979,6 +2014,15 @@ class ResponseTests(TestCase):
     """
     Tests for L{Response}.
     """
+
+    def test_verifyInterface(self):
+        """
+        L{Response} instances provide L{IResponse}.
+        """
+        response = justTransportResponse(StringTransport())
+        self.assertTrue(verifyObject(IResponse, response))
+
+
     def test_makeConnection(self):
         """
         The L{IProtocol} provider passed to L{Response.deliverBody} has its
